Index: net/ssl/client_cert_store_mac.h |
diff --git a/net/ssl/client_cert_store_mac.h b/net/ssl/client_cert_store_mac.h |
index 1bad779dd35377fb284356148a9d8eb1f1f5bd3d..cc06ec60a9104de91dd0ed784689e8ff73c48b44 100644 |
--- a/net/ssl/client_cert_store_mac.h |
+++ b/net/ssl/client_cert_store_mac.h |
@@ -26,24 +26,24 @@ class NET_EXPORT ClientCertStoreMac : public ClientCertStore { |
friend class ClientCertStoreMacTest; |
friend class ClientCertStoreMacTestDelegate; |
- // A hook for testing. Filters |input_certs| using the logic being used to |
- // filter the system store when GetClientCerts() is called. |
- // Implemented by creating a list of certificates that otherwise would be |
- // extracted from the system store and filtering it using the common logic |
- // (less adequate than the approach used on Windows). |
- bool SelectClientCertsForTesting(const CertificateList& input_certs, |
+ // A hook for testing. Filters |input_identities| using the logic being used |
+ // to filter the system store when GetClientCerts() is called. Implemented by |
+ // creating a list of certificates that otherwise would be extracted from the |
+ // system store and filtering it using the common logic (less adequate than |
+ // the approach used on Windows). |
+ bool SelectClientCertsForTesting(ClientCertIdentityList input_identities, |
const SSLCertRequestInfo& cert_request_info, |
- CertificateList* selected_certs); |
+ ClientCertIdentityList* selected_identities); |
// Testing hook specific to Mac, where the internal logic recognizes preferred |
// certificates for particular domains. If the preferred certificate is |
// present in the output list (i.e. it doesn't get filtered out), it should |
// always come first. |
bool SelectClientCertsGivenPreferredForTesting( |
- const scoped_refptr<X509Certificate>& preferred_cert, |
- const CertificateList& regular_certs, |
+ std::unique_ptr<ClientCertIdentity> preferred_identity, |
+ ClientCertIdentityList regular_identities, |
const SSLCertRequestInfo& request, |
- CertificateList* selected_certs); |
+ ClientCertIdentityList* selected_identities); |
DISALLOW_COPY_AND_ASSIGN(ClientCertStoreMac); |
}; |